use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alan
Alders
Alessandro
Berry
BooK
Brad
Bright
Bruhat
CA
CGI
Chris
Christian
Claes
Clinton
Cook
Craig
Dan
David
Davis
Dean
Doherty
Edward
Eklund
Etheridge
Evans
Felipe
Gardner
Gasper
Ghedini
Gilbert
Golden
Gormley
Graham
Grazzini
Greg
Guimard
HTTP
Hansen
Horsfall
Hukins
Jakobsson
James
Jeremy
Jess
Kaji
Karen
Keenan
Kennedy
Knop
Kornetzki
Lukas
Martin
Mates
Matthew
Mengué
Michael
Mike
Mitchell
Miyagawa
Mueller
Nehren
Nicolas
Olaf
Olivier
Palmquist
Pearce
Petr
Philippe
Písař
RFC7230
RFC7231
RFC7232
RFC7233
RFC7234
RFC7235
Raspass
Rob
Robinson
Rochelemagne
Serguei
Shoichi
Sinan
SkyMarshal
Steve
Stevens
Stig
Syohei
Sören
TLS
Tatsuhiko
Tiny
Tom
Tony
Trouchelle
Tunnelling
UA
Unur
Weyl
Xavier
YOSHIDA
Zborowski
al3xbio
apeiron
bgills
book
brian
carlson
castaway
chansen
claes
clint
craigberry
cweyl
dagolden
davem
doherty
dolmen
ed
ether
felipe
gardner
git
grinnz
haarg
jkeenan
jmates
jraspass
kennedy
leklund
lib
michael
miyagawa
mjegh
mlbright
mrdvt92
nanis
olaf
pearce
ppisar
proxying
robm
rochelemagne
sandals
sanjay
skaji
skymarshal1729
snjkmr32
soeren
steve
stro
syohex
tom
tony
wolfsage
xdg
yadd
